WalletClient

Struct WalletClient 

pub struct WalletClient<T> { /* private fields */ }

Implementations

Source

impl WalletClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> WalletClient<T>
where T: GrpcService<BoxBody>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> WalletClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>, <T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn get_account( &mut self, request: impl IntoRequest<Account>, ) -> Result<Response<Account>, Status>

pub async fn get_account_by_id( &mut self, request: impl IntoRequest<Account>, ) -> Result<Response<Account>, Status>

pub async fn get_account_balance( &mut self, request: impl IntoRequest<AccountBalanceRequest>, ) -> Result<Response<AccountBalanceResponse>, Status>

pub async fn get_block_balance_trace( &mut self, request: impl IntoRequest<BlockIdentifier>, ) -> Result<Response<BlockBalanceTrace>, Status>

pub async fn create_transaction( &mut self, request: impl IntoRequest<TransferContract>, ) -> Result<Response<Transaction>, Status>

Please use CreateTransaction2 instead of this function.

pub async fn create_transaction2( &mut self, request: impl IntoRequest<TransferContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of CreateTransaction.

pub async fn broadcast_transaction( &mut self, request: impl IntoRequest<Transaction>, ) -> Result<Response<Return>, Status>

pub async fn update_account( &mut self, request: impl IntoRequest<AccountUpdateContract>, ) -> Result<Response<Transaction>, Status>

Please use UpdateAccount2 instead of this function.

pub async fn set_account_id( &mut self, request: impl IntoRequest<SetAccountIdContract>, ) -> Result<Response<Transaction>, Status>

pub async fn update_account2( &mut self, request: impl IntoRequest<AccountUpdateContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of UpdateAccount.

pub async fn vote_witness_account( &mut self, request: impl IntoRequest<VoteWitnessContract>, ) -> Result<Response<Transaction>, Status>

Please use VoteWitnessAccount2 instead of this function.

pub async fn update_setting( &mut self, request: impl IntoRequest<UpdateSettingContract>, ) -> Result<Response<TransactionExtention>, Status>

modify the consume_user_resource_percent

pub async fn update_energy_limit( &mut self, request: impl IntoRequest<UpdateEnergyLimitContract>, ) -> Result<Response<TransactionExtention>, Status>

modify the energy_limit

pub async fn vote_witness_account2( &mut self, request: impl IntoRequest<VoteWitnessContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of VoteWitnessAccount.

pub async fn create_asset_issue( &mut self, request: impl IntoRequest<AssetIssueContract>, ) -> Result<Response<Transaction>, Status>

Please use CreateAssetIssue2 instead of this function.

pub async fn create_asset_issue2( &mut self, request: impl IntoRequest<AssetIssueContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of CreateAssetIssue.

pub async fn update_witness( &mut self, request: impl IntoRequest<WitnessUpdateContract>, ) -> Result<Response<Transaction>, Status>

Please use UpdateWitness2 instead of this function.

pub async fn update_witness2( &mut self, request: impl IntoRequest<WitnessUpdateContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of UpdateWitness.

pub async fn create_account( &mut self, request: impl IntoRequest<AccountCreateContract>, ) -> Result<Response<Transaction>, Status>

Please use CreateAccount2 instead of this function.

pub async fn create_account2( &mut self, request: impl IntoRequest<AccountCreateContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of CreateAccount.

pub async fn create_witness( &mut self, request: impl IntoRequest<WitnessCreateContract>, ) -> Result<Response<Transaction>, Status>

Please use CreateWitness2 instead of this function.

pub async fn create_witness2( &mut self, request: impl IntoRequest<WitnessCreateContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of CreateWitness.

pub async fn transfer_asset( &mut self, request: impl IntoRequest<TransferAssetContract>, ) -> Result<Response<Transaction>, Status>

Please use TransferAsset2 instead of this function.

pub async fn transfer_asset2( &mut self, request: impl IntoRequest<TransferAssetContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of TransferAsset.

pub async fn participate_asset_issue( &mut self, request: impl IntoRequest<ParticipateAssetIssueContract>, ) -> Result<Response<Transaction>, Status>

Please use ParticipateAssetIssue2 instead of this function.

pub async fn participate_asset_issue2( &mut self, request: impl IntoRequest<ParticipateAssetIssueContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of ParticipateAssetIssue.

pub async fn freeze_balance( &mut self, request: impl IntoRequest<FreezeBalanceContract>, ) -> Result<Response<Transaction>, Status>

Please use FreezeBalance2 instead of this function.

pub async fn freeze_balance2( &mut self, request: impl IntoRequest<FreezeBalanceContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of FreezeBalance.

pub async fn freeze_balance_v2( &mut self, request: impl IntoRequest<FreezeBalanceV2Contract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function when FreezeBalanceV2.

pub async fn unfreeze_balance( &mut self, request: impl IntoRequest<UnfreezeBalanceContract>, ) -> Result<Response<Transaction>, Status>

Please use UnfreezeBalance2 instead of this function.

pub async fn unfreeze_balance2( &mut self, request: impl IntoRequest<UnfreezeBalanceContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of UnfreezeBalance.

pub async fn unfreeze_balance_v2( &mut self, request: impl IntoRequest<UnfreezeBalanceV2Contract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function when UnfreezeBalanceV2.

pub async fn unfreeze_asset( &mut self, request: impl IntoRequest<UnfreezeAssetContract>, ) -> Result<Response<Transaction>, Status>

Please use UnfreezeAsset2 instead of this function.

pub async fn unfreeze_asset2( &mut self, request: impl IntoRequest<UnfreezeAssetContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of UnfreezeAsset.

pub async fn withdraw_balance( &mut self, request: impl IntoRequest<WithdrawBalanceContract>, ) -> Result<Response<Transaction>, Status>

Please use WithdrawBalance2 instead of this function.

pub async fn withdraw_balance2( &mut self, request: impl IntoRequest<WithdrawBalanceContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of WithdrawBalance.

pub async fn withdraw_expire_unfreeze( &mut self, request: impl IntoRequest<WithdrawExpireUnfreezeContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn delegate_resource( &mut self, request: impl IntoRequest<DelegateResourceContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn un_delegate_resource( &mut self, request: impl IntoRequest<UnDelegateResourceContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn cancel_all_unfreeze_v2( &mut self, request: impl IntoRequest<CancelAllUnfreezeV2Contract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn update_asset( &mut self, request: impl IntoRequest<UpdateAssetContract>, ) -> Result<Response<Transaction>, Status>

Please use UpdateAsset2 instead of this function.

pub async fn update_asset2( &mut self, request: impl IntoRequest<UpdateAssetContract>, ) -> Result<Response<TransactionExtention>, Status>

Use this function instead of UpdateAsset.

pub async fn proposal_create( &mut self, request: impl IntoRequest<ProposalCreateContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn proposal_approve( &mut self, request: impl IntoRequest<ProposalApproveContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn proposal_delete( &mut self, request: impl IntoRequest<ProposalDeleteContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn buy_storage( &mut self, request: impl IntoRequest<BuyStorageContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn buy_storage_bytes( &mut self, request: impl IntoRequest<BuyStorageBytesContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn sell_storage( &mut self, request: impl IntoRequest<SellStorageContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn exchange_create( &mut self, request: impl IntoRequest<ExchangeCreateContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn exchange_inject( &mut self, request: impl IntoRequest<ExchangeInjectContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn exchange_withdraw( &mut self, request: impl IntoRequest<ExchangeWithdrawContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn exchange_transaction( &mut self, request: impl IntoRequest<ExchangeTransactionContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn market_sell_asset( &mut self, request: impl IntoRequest<MarketSellAssetContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn market_cancel_order( &mut self, request: impl IntoRequest<MarketCancelOrderContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn get_market_order_by_id( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<MarketOrder>, Status>

pub async fn get_market_order_by_account( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<MarketOrderList>, Status>

pub async fn get_market_price_by_pair( &mut self, request: impl IntoRequest<MarketOrderPair>, ) -> Result<Response<MarketPriceList>, Status>

pub async fn get_market_order_list_by_pair( &mut self, request: impl IntoRequest<MarketOrderPair>, ) -> Result<Response<MarketOrderList>, Status>

pub async fn get_market_pair_list( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<MarketOrderPairList>, Status>

pub async fn list_nodes( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<NodeList>, Status>

pub async fn get_asset_issue_by_account( &mut self, request: impl IntoRequest<Account>, ) -> Result<Response<AssetIssueList>, Status>

pub async fn get_account_net( &mut self, request: impl IntoRequest<Account>, ) -> Result<Response<AccountNetMessage>, Status>

pub async fn get_account_resource( &mut self, request: impl IntoRequest<Account>, ) -> Result<Response<AccountResourceMessage>, Status>

pub async fn get_asset_issue_by_name( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<AssetIssueContract>, Status>

pub async fn get_asset_issue_list_by_name( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<AssetIssueList>, Status>

pub async fn get_asset_issue_by_id( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<AssetIssueContract>, Status>

pub async fn get_now_block( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<Block>, Status>

Please use GetNowBlock2 instead of this function.

pub async fn get_now_block2( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<BlockExtention>, Status>

Use this function instead of GetNowBlock.

pub async fn get_block_by_num( &mut self, request: impl IntoRequest<NumberMessage>, ) -> Result<Response<Block>, Status>

Please use GetBlockByNum2 instead of this function.

pub async fn get_block_by_num2( &mut self, request: impl IntoRequest<NumberMessage>, ) -> Result<Response<BlockExtention>, Status>

Use this function instead of GetBlockByNum.

pub async fn get_transaction_count_by_block_num( &mut self, request: impl IntoRequest<NumberMessage>, ) -> Result<Response<NumberMessage>, Status>

pub async fn get_block_by_id( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<Block>, Status>

pub async fn get_block_by_limit_next( &mut self, request: impl IntoRequest<BlockLimit>, ) -> Result<Response<BlockList>, Status>

Please use GetBlockByLimitNext2 instead of this function.

pub async fn get_block_by_limit_next2( &mut self, request: impl IntoRequest<BlockLimit>, ) -> Result<Response<BlockListExtention>, Status>

Use this function instead of GetBlockByLimitNext.

pub async fn get_block_by_latest_num( &mut self, request: impl IntoRequest<NumberMessage>, ) -> Result<Response<BlockList>, Status>

Please use GetBlockByLatestNum2 instead of this function.

pub async fn get_block_by_latest_num2( &mut self, request: impl IntoRequest<NumberMessage>, ) -> Result<Response<BlockListExtention>, Status>

Use this function instead of GetBlockByLatestNum.

pub async fn get_transaction_by_id( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<Transaction>, Status>

pub async fn deploy_contract( &mut self, request: impl IntoRequest<CreateSmartContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn get_contract( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<SmartContract>, Status>

pub async fn get_contract_info( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<SmartContractDataWrapper>, Status>

pub async fn trigger_contract( &mut self, request: impl IntoRequest<TriggerSmartContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn trigger_constant_contract( &mut self, request: impl IntoRequest<TriggerSmartContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn estimate_energy( &mut self, request: impl IntoRequest<TriggerSmartContract>, ) -> Result<Response<EstimateEnergyMessage>, Status>

pub async fn clear_contract_abi( &mut self, request: impl IntoRequest<ClearAbiContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn list_witnesses( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<WitnessList>, Status>

pub async fn get_delegated_resource( &mut self, request: impl IntoRequest<DelegatedResourceMessage>, ) -> Result<Response<DelegatedResourceList>, Status>

pub async fn get_delegated_resource_v2( &mut self, request: impl IntoRequest<DelegatedResourceMessage>, ) -> Result<Response<DelegatedResourceList>, Status>

pub async fn get_delegated_resource_account_index( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<DelegatedResourceAccountIndex>, Status>

pub async fn get_delegated_resource_account_index_v2( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<DelegatedResourceAccountIndex>, Status>

pub async fn get_can_delegated_max_size( &mut self, request: impl IntoRequest<CanDelegatedMaxSizeRequestMessage>, ) -> Result<Response<CanDelegatedMaxSizeResponseMessage>, Status>

pub async fn get_available_unfreeze_count( &mut self, request: impl IntoRequest<GetAvailableUnfreezeCountRequestMessage>, ) -> Result<Response<GetAvailableUnfreezeCountResponseMessage>, Status>

pub async fn get_can_withdraw_unfreeze_amount( &mut self, request: impl IntoRequest<CanWithdrawUnfreezeAmountRequestMessage>, ) -> Result<Response<CanWithdrawUnfreezeAmountResponseMessage>, Status>

pub async fn list_proposals( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<ProposalList>, Status>

pub async fn get_paginated_proposal_list( &mut self, request: impl IntoRequest<PaginatedMessage>, ) -> Result<Response<ProposalList>, Status>

pub async fn get_proposal_by_id( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<Proposal>, Status>

pub async fn list_exchanges( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<ExchangeList>, Status>

pub async fn get_paginated_exchange_list( &mut self, request: impl IntoRequest<PaginatedMessage>, ) -> Result<Response<ExchangeList>, Status>

pub async fn get_exchange_by_id( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<Exchange>, Status>

pub async fn get_chain_parameters( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<ChainParameters>, Status>

pub async fn get_asset_issue_list( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<AssetIssueList>, Status>

pub async fn get_paginated_asset_issue_list( &mut self, request: impl IntoRequest<PaginatedMessage>, ) -> Result<Response<AssetIssueList>, Status>

pub async fn total_transaction( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<NumberMessage>, Status>

pub async fn get_next_maintenance_time( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<NumberMessage>, Status>

pub async fn get_transaction_info_by_id( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<TransactionInfo>, Status>

pub async fn account_permission_update( &mut self, request: impl IntoRequest<AccountPermissionUpdateContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn get_transaction_sign_weight( &mut self, request: impl IntoRequest<Transaction>, ) -> Result<Response<TransactionSignWeight>, Status>

pub async fn get_transaction_approved_list( &mut self, request: impl IntoRequest<Transaction>, ) -> Result<Response<TransactionApprovedList>, Status>

pub async fn get_node_info( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<NodeInfo>, Status>

pub async fn get_reward_info( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<NumberMessage>, Status>

pub async fn get_brokerage_info( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<NumberMessage>, Status>

pub async fn update_brokerage( &mut self, request: impl IntoRequest<UpdateBrokerageContract>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn create_shielded_transaction( &mut self, request: impl IntoRequest<PrivateParameters>, ) -> Result<Response<TransactionExtention>, Status>

for shiededTransaction

pub async fn get_merkle_tree_voucher_info( &mut self, request: impl IntoRequest<OutputPointInfo>, ) -> Result<Response<IncrementalMerkleVoucherInfo>, Status>

pub async fn scan_note_by_ivk( &mut self, request: impl IntoRequest<IvkDecryptParameters>, ) -> Result<Response<DecryptNotes>, Status>

pub async fn scan_and_mark_note_by_ivk( &mut self, request: impl IntoRequest<IvkDecryptAndMarkParameters>, ) -> Result<Response<DecryptNotesMarked>, Status>

pub async fn scan_note_by_ovk( &mut self, request: impl IntoRequest<OvkDecryptParameters>, ) -> Result<Response<DecryptNotes>, Status>

pub async fn get_spending_key( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<BytesMessage>, Status>

pub async fn get_expanded_spending_key( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<ExpandedSpendingKeyMessage>, Status>

pub async fn get_ak_from_ask( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<BytesMessage>, Status>

pub async fn get_nk_from_nsk( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<BytesMessage>, Status>

pub async fn get_incoming_viewing_key( &mut self, request: impl IntoRequest<ViewingKeyMessage>, ) -> Result<Response<IncomingViewingKeyMessage>, Status>

pub async fn get_diversifier( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<DiversifierMessage>, Status>

pub async fn get_new_shielded_address( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<ShieldedAddressInfo>, Status>

pub async fn get_zen_payment_address( &mut self, request: impl IntoRequest<IncomingViewingKeyDiversifierMessage>, ) -> Result<Response<PaymentAddressMessage>, Status>

pub async fn get_rcm( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<BytesMessage>, Status>

pub async fn is_spend( &mut self, request: impl IntoRequest<NoteParameters>, ) -> Result<Response<SpendResult>, Status>

pub async fn create_shielded_transaction_without_spend_auth_sig( &mut self, request: impl IntoRequest<PrivateParametersWithoutAsk>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn get_shield_transaction_hash( &mut self, request: impl IntoRequest<Transaction>, ) -> Result<Response<BytesMessage>, Status>

pub async fn create_spend_auth_sig( &mut self, request: impl IntoRequest<SpendAuthSigParameters>, ) -> Result<Response<BytesMessage>, Status>

pub async fn create_shield_nullifier( &mut self, request: impl IntoRequest<NfParameters>, ) -> Result<Response<BytesMessage>, Status>

pub async fn create_shielded_contract_parameters( &mut self, request: impl IntoRequest<PrivateShieldedTrc20Parameters>, ) -> Result<Response<ShieldedTrc20Parameters>, Status>

for shielded contract

pub async fn create_shielded_contract_parameters_without_ask( &mut self, request: impl IntoRequest<PrivateShieldedTrc20ParametersWithoutAsk>, ) -> Result<Response<ShieldedTrc20Parameters>, Status>

pub async fn scan_shielded_trc20_notes_by_ivk( &mut self, request: impl IntoRequest<IvkDecryptTrc20Parameters>, ) -> Result<Response<DecryptNotesTrc20>, Status>

pub async fn scan_shielded_trc20_notes_by_ovk( &mut self, request: impl IntoRequest<OvkDecryptTrc20Parameters>, ) -> Result<Response<DecryptNotesTrc20>, Status>

pub async fn is_shielded_trc20_contract_note_spent( &mut self, request: impl IntoRequest<NfTrc20Parameters>, ) -> Result<Response<NullifierResult>, Status>

pub async fn get_trigger_input_for_shielded_trc20_contract( &mut self, request: impl IntoRequest<ShieldedTrc20TriggerContractParameters>, ) -> Result<Response<BytesMessage>, Status>

pub async fn create_common_transaction( &mut self, request: impl IntoRequest<Transaction>, ) -> Result<Response<TransactionExtention>, Status>

pub async fn get_transaction_info_by_block_num( &mut self, request: impl IntoRequest<NumberMessage>, ) -> Result<Response<TransactionInfoList>, Status>

pub async fn get_burn_trx( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<NumberMessage>, Status>

pub async fn get_transaction_from_pending( &mut self, request: impl IntoRequest<BytesMessage>, ) -> Result<Response<Transaction>, Status>

pub async fn get_transaction_list_from_pending( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<TransactionIdList>, Status>

pub async fn get_pending_size( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<NumberMessage>, Status>

pub async fn get_block( &mut self, request: impl IntoRequest<BlockReq>, ) -> Result<Response<BlockExtention>, Status>

pub async fn get_bandwidth_prices( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<PricesResponseMessage>, Status>

pub async fn get_energy_prices( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<PricesResponseMessage>, Status>

pub async fn get_memo_fee( &mut self, request: impl IntoRequest<EmptyMessage>, ) -> Result<Response<PricesResponseMessage>, Status>